==> RealiBoxTestBiz-0.6.6.tar.gz: RealiBoxTestBiz-0.6.6/realiboxtestbiz/utils/RealiBoxRequestBase.py <==
'''
执行接口请求的驱动方法
集成的功能
    1、输入输出数据的json格式本地化。
    2、debug模式
    3、生成每一次请求的请求id()
'''
import traceback
import uuid
import json
from .sub_string_template import sub_string_template


class RequestMeta(type):
    def req_json_template(self, req_json, case_object):
        '''将请求的req_json进行字符串模版替换环境变量'''
        # req_json转字符串
        req_json_str = json.dumps(req_json, indent=2, ensure_ascii=False)
        req_json_str = sub_string_template(req_json_str, case_object.V)
        return json.loads(req_json_str)

    def __call__(self, *args, **kwargs):
        Object = self.__new__(self, *args, **kwargs)
        # 用例类对象
        case_object = args[0]

        # 获取到传过来的 req_json 数据。
        req_json = self.req_json_template(kwargs.get('req_json'), case_object)

        try:
            # 解析输入的json内容， 使用用例对象的session进行请求
            response_object = case_object.session.request(**req_json)

        except Exception:  # 请求异常
            response_object = traceback.format_exc()
        # 将响应对象传递给用例类
        case_object.current_response_object = response_object
        # 响应对象传递给 RealiBoxRequestDriver.__init__() 中执行初始化
        self.__init__(Object, case_object=case_object, req_json=req_json, response_object=response_object)
        return Object


class RealiBoxRequestBase(metaclass=RequestMeta):
    '''
    将 RealiBoxRequestDriver 集成到测试基类 RealiBoxTestBiz 中
    生成实例对象时实现：
        1、获取输入json，完成解析，请求，并将结果传入生成的实例对象中作为类属性
    '''

    def __init__(self, *args, **kwargs):
        # 生成一个请求的uuid
        uid = uuid.uuid1().hex
        # 用例类对象
        case_object = kwargs.get('case_object')
        # 用于请求的json数据(环境变量替换后的数据)
        req_json = kwargs.get('req_json')
        # 响应对象
        self.RESPONSE = kwargs.get('response_object')
        # 获取响应json()报文
        #   1、请求异常情况， 响应内容为报错信息
        if isinstance(self.RESPONSE, str):
            resp_json = {'__TEXT__': self.RESPONSE}
        else:
            try:
                resp_json = self.RESPONSE.json()
            except Exception:
                resp_json = {'__TEXT__': self.RESPONSE.text}

        # 在 在步骤的请求列表中追加请求信息
        case_object.step_requests_list.append({
            uid: {
                'INPUT': req_json,
                'OUTPUT': resp_json
            }
        })

==> RealiBoxTestBiz-0.8.6.tar.gz: RealiBoxTestBiz-0.8.6/realiboxtestbiz/utils/RealiBoxRequestBase.py <==
'''
执行接口请求的驱动方法
集成的功能
    1、输入输出数据的json格式本地化。
    2、debug模式
    3、生成每一次请求的请求id()
'''
import traceback
import uuid
from .req_json_machining import req_json_machining


class RequestMeta(type):

    def __call__(self, *args, **kwargs):
        Object = self.__new__(self, *args, **kwargs)
        # 用例类对象
        case_object = args[0]

        # 获取到传过来的 req_json 数据。
        req_json, req_json_cp = req_json_machining(kwargs.get('req_json'), case_object.V)

        try:
            # 解析输入的json内容， 使用用例对象的session进行请求
            response_object = case_object.session.request(**req_json)

        except Exception:  # 请求异常
            response_object = traceback.format_exc()
        # 将响应对象传递给用例类
        case_object.current_response_object = response_object
        # 响应对象传递给 RealiBoxRequestDriver.__init__() 中执行初始化
        self.__init__(Object, case_object=case_object, req_json=req_json_cp, response_object=response_object)
        return Object


class RealiBoxRequestBase(metaclass=RequestMeta):
    '''
    将 RealiBoxRequestDriver 集成到测试基类 RealiBoxTestBiz 中
    生成实例对象时实现：
        1、获取输入json，完成解析，请求，并将结果传入生成的实例对象中作为类属性
    '''

    def __init__(self, *args, **kwargs):
        # 生成一个请求的uuid
        uid = uuid.uuid1().hex
        # 用例类对象
        case_object = kwargs.get('case_object')
        # 用于请求的json数据(环境变量替换后的数据)
        req_json = kwargs.get('req_json')
        # 响应对象
        self.RESPONSE = kwargs.get('response_object')
        # 获取响应json()报文
        #   1、请求异常情况， 响应内容为报错信息
        if isinstance(self.RESPONSE, str):
            resp_json = {'__TEXT__': self.RESPONSE}
        else:
            try:
                resp_json = self.RESPONSE.json()
            except Exception:
                resp_json = {'__TEXT__': self.RESPONSE.text}

        # 在 在步骤的请求列表中追加请求信息
        case_object.step_requests_list.append({
            uid: {
                'INPUT': req_json,
                'OUTPUT': resp_json
            }
        })
